@@ -3,12 +3,12 @@ package Dancer2::Session::CHI;
 
 use strict;
 use warnings;
- 
+
 use Moo;
 use CHI;
 use Type::Tiny;
 use Types::Standard qw/ Str ArrayRef InstanceOf HashRef/;
- 
+
 #
 # Public attributes
 #
@@ -34,29 +34,29 @@ has _chi => (
         _destroy => 'remove',
     },
 );
- 
+
 # Session methods
 sub _retrieve {
     my ($self) = shift;
- 
+
     return $self->_chi->get( @_ );
 }
- 
+
 sub _flush {
     my ($self) = shift;
- 
+
     return $self->_chi->set( @_ );
 }
- 
+
 sub _build__chi {
     my ($self) = @_;
- 
+
     return CHI->new(
         driver => $self->driver,
         %{ $self->driver_args },
     );
 }
- 
+
 around BUILDARGS => sub {
     my $orig  = shift;
     my $class = shift;
@@ -72,15 +72,15 @@ around BUILDARGS => sub {
 # Role composition
 #
 with 'Dancer2::Core::Role::SessionFactory';
- 
+
 sub _sessions { my $self = shift; return $self->_chi->get_keys; }
- 
+
 sub _change_id {
     my ( $self, $old_id, $new_id ) = @_;
     $self->_flush( $new_id, $self->_retrieve( $old_id ) );
     $self->_destroy( $old_id );
 }
- 
+
 1;
 
 __END__
@@ -95,7 +95,7 @@ Dancer2::Session::CHI - Dancer 2 session storage with CHI backend
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -111,13 +111,13 @@ version 0.04
 =head1 DESCRIPTION
 
 This module implements a session factory for L<Dancer2> that stores session
-state using L<CHI>. 
+state using L<CHI>.
 
 =head1 ATTRIBUTES
 
 =head2 driver (required)
 
-The backend driver CHI will use to store the session data. Any additional 
+The backend driver CHI will use to store the session data. Any additional
 attributes beyond the driver will be passed as additional configuration
 parameters to CHI.
 
@@ -133,18 +133,23 @@ parameters to CHI.
 
 =back
 
-=head1 CREDITS 
+=head1 CREDITS
 
 This is heavily based on L<Dancer2::Session::Memcached> by David Golden and
 Yanick Champoux.
 
 =head2 Contributors
 
-The following people have contributes to C<Dancer2::Session::CHI> in some way,
+The following people have contributed to C<Dancer2::Session::CHI> in some way,
 either through bug reports, code, suggestions, or moral support:
 
-andk
-Mohammad S Anwar
+=over
+
+=item andk
+
+=item Mohammad S Anwar
+
+=back
 
 =head1 AUTHOR
 
@@ -152,7 +157,7 @@ Jason A. Crome <cromedome@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Jason A. Crome.
+This software is copyright (c) 2023 by Jason A. Crome.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
